pub struct CoffObject {
pub header: CoffHeader,
pub sections: Vec<CoffSection>,
pub symbols: Vec<CoffSymbol>,
pub string_table: Vec<u8>,
}Expand description
COFF object file structure
Represents a complete COFF object file, containing header, sections, symbol table, etc. COFF object files are intermediate files generated by compilers, containing unlinked code and data.
Fields
header: CoffHeaderCOFF header info
sections: Vec<CoffSection>Collection of all sections
symbols: Vec<CoffSymbol>Symbol table containing all symbol info
string_table: Vec<u8>String table for storing long symbol names