pub struct CoffRelocation {
pub virtual_address: u32,
pub symbol_table_index: u32,
pub relocation_type: u16,
}Expand description
COFF relocation item
Represents an item that requires address relocation at link time. Relocation is the process of converting relative addresses to absolute addresses.
Fields
virtual_address: u32Virtual address that needs relocation
symbol_table_index: u32Symbol table index pointing to the related symbol
relocation_type: u16Relocation type, defining how to perform the relocation
Implementations