pub enum SubsystemType {
Console,
Windows,
Native,
Posix,
WindowsCe,
Efi,
EfiBootServiceDriver,
EfiRuntimeDriver,
EfiRom,
Xbox,
WindowsBootApplication,
}Expand description
PE subsystem type enum
Defines the various subsystem types that a Windows PE file can use, which determine the runtime environment and dependencies of the program.
Variants
Console
Console application, runs in a console window
Windows
Windows GUI application, has a graphical interface
Native
Native driver, runs in kernel mode
Posix
POSIX subsystem application
WindowsCe
Windows CE subsystem
Efi
EFI application
EfiBootServiceDriver
EFI boot service driver
EfiRuntimeDriver
EFI runtime driver
EfiRom
EFI ROM image
Xbox
Xbox application
WindowsBootApplication
Windows boot application