pub struct CoffHeader {
pub machine: u16,
pub number_of_sections: u16,
pub time_date_stamp: u32,
pub pointer_to_symbol_table: u32,
pub number_of_symbols: u32,
pub size_of_optional_header: u16,
pub characteristics: u16,
}Expand description
COFF file header structure
Contains basic information for the COFF (Common Object File Format) format, defining key information such as target machine type, number of sections, and timestamp.
Fields
machine: u16Target machine type, such as x86, x64, ARM, etc.
number_of_sections: u16Number of sections in the file
time_date_stamp: u32Timestamp indicating when the file was created or linked
pointer_to_symbol_table: u32File offset of the symbol table, or 0 if none exists
number_of_symbols: u32Number of symbols in the symbol table
size_of_optional_header: u16Size of the optional header in bytes
characteristics: u16File characteristics flags describing various attributes of the file
Implementations
Sourceimpl CoffHeader
impl CoffHeader
Sourcepub fn new(machine: u16, number_of_sections: u16) -> Self
pub fn new(machine: u16, number_of_sections: u16) -> Self
Create a new COFF header with core fields
Sourcepub fn with_timestamp(self, time_date_stamp: u32) -> Self
pub fn with_timestamp(self, time_date_stamp: u32) -> Self
Set timestamp
Sourcepub fn with_symbol_table(
self,
pointer_to_symbol_table: u32,
number_of_symbols: u32,
) -> Self
pub fn with_symbol_table( self, pointer_to_symbol_table: u32, number_of_symbols: u32, ) -> Self
Set symbol table information
Sourcepub fn with_optional_header_size(self, size_of_optional_header: u16) -> Self
pub fn with_optional_header_size(self, size_of_optional_header: u16) -> Self
Set optional header size
Sourcepub fn with_characteristics(self, characteristics: u16) -> Self
pub fn with_characteristics(self, characteristics: u16) -> Self
Set file characteristics
pub fn read<R: Read>(reader: R) -> Result<Self, GaiaError>
pub fn get_architecture(&self) -> Architecture